pub struct WorktreeRoots {
pub old_root: Option<PathBuf>,
pub new_root: Option<PathBuf>,
}Available on crate feature
blob only.Expand description
A way to access roots for different kinds of resources that are possibly located and accessible in a worktree.
Fields
old_root: Option<PathBuf>A place where the source of a rewrite, rename or copy, or generally the previous version of resources, are located.
new_root: Option<PathBuf>A place where the destination of a rewrite, rename or copy, or generally the new version of resources, are located.
Implementations