Operation

Enum Operation 

pub enum Operation<'a> {
    InternalDiff {
        algorithm: Algorithm,
    },
    ExternalCommand {
        command: &'a BStr,
    },
    SourceOrDestinationIsBinary,
}
Available on crate feature blob only.
The kind of operation that should be performed based on the configuration of the resources involved in the diff.

Variants



InternalDiff

The internal diff algorithm should be computed with crate::blob::Diff::compute(). This only happens if none of the resources are binary, and if there is no external diff program configured via git-attributes or Options::skip_internal_diff_if_external_is_configured is false.

Use Outcome::interned_input() to easily obtain an interner for use with crate::blob::Diff::compute(), or maintain one yourself for greater reuse.

Fields

algorithm: Algorithm

The algorithm we determined should be used, which is one of (in order, first set one wins):

  • the driver’s override
  • the platforms own configuration (typically from git-config)
  • the default algorithm


ExternalCommand

Run the external diff program according as configured in the source-resources driver. This only happens if Options::skip_internal_diff_if_external_is_configured was true, preventing the usage of the internal diff implementation.

Fields

command: &'a BStr

The command as extracted from Driver::command. Use it in Platform::prepare_diff_command to easily prepare a compatible invocation.



SourceOrDestinationIsBinary

One of the involved resources, old or new, was binary and thus no diff can be performed.