Module resource

Module resource 

Available on crate feature blob only.
Structs

ByteLinesWithoutTerminator
A token source that splits bytes into lines while removing trailing newline separators.

Enums

Data
The data of a diffable resource, as it could be determined and computed previously.