bstr_lines

Function bstr_lines 

pub fn bstr_lines(data: &BStr) -> BStrLines<'_> 
Available on crate feature blob only.
Returns a TokenSource that uses the lines in data as Tokens. The newline separator (\r\n or \n) is included in the emitted tokens. This means that changing the newline separator from \r\n to \n (or omitting it fully on the last line) is detected when computing a Diff.