UnifiedDiff

Struct UnifiedDiff 

pub struct UnifiedDiff<'a, T, D>
where T: Hash + Eq + AsRef<[u8]>, D: ConsumeHunk,
{ /* private fields */ }
Available on crate feature blob only.
A helper that renders a Diff as unified diff output. It can be used to create a textual diff in the format typically output by git or gnu-diff if the -u option is used.

Implementations

Source

impl<'a, T, D> UnifiedDiff<'a, T, D>
where T: Hash + Eq + AsRef<[u8]>, D: ConsumeHunk,

pub fn new( diff: &'a Diff, input: &'a InternedInput<T>, consume_hunk: D, context_size: ContextSize, ) -> Self

Create a new instance to create a unified diff from diff using the lines in input. context_size is the amount of lines around each hunk which will be passed to consume_hunk.

consume_hunk is called for each hunk with all the information required to create a unified diff.

pub fn consume(self) -> Result<D::Out>

Consume all hunks from diff and return the delegate’s final output.