Available on crate feature
blob only.Expand description
Types related to the rename tracker for renames, rewrites and copies.
Deviation
Note that the algorithm implemented here is in many ways different from what git does.
- it’s less sophisticated than
git, but prefers a candidate whose file name matches the destination’s in identity matches, and uses that as a tie-breaker for similarity matches. - the set used for copy-detection is probably smaller by default.
Modules
- emit
- visit
- A module with types used in the user-callback in Tracker::emit().
Enums
- Change
Kind - The kind of a change.