pub fn words(data: &str) -> Words<'_> ⓘAvailable on crate feature
blob only.Expand description
Returns a TokenSource that uses the words in data as Tokens. A word is
a sequence of alphanumeric characters as determined by
char::is_alphanumeric, or a sequence of just the space character ’ ’. Any
other characters are their own word.