pub struct IndentHeuristic<IndentOfToken> { /* private fields */ }Available on crate feature
blob only.Expand description
A slider heuristic that uses indentation levels to determine the best hunk position.
This heuristic analyzes the indentation of lines surrounding potential hunk positions and chooses the position that results in the most intuitive diff for human readers. It’s particularly effective for code and other indented text.
Implementations
Sourceimpl<IndentOfToken> IndentHeuristic<IndentOfToken>
impl<IndentOfToken> IndentHeuristic<IndentOfToken>
Sourcepub fn new(indent_of_token: IndentOfToken) -> IndentHeuristic<IndentOfToken>
pub fn new(indent_of_token: IndentOfToken) -> IndentHeuristic<IndentOfToken>
Creates a new IndentHeuristic with the given indentation function.
Parameters
indent_of_token- A function that takes a token and returns its indentation level