pub struct UnifiedDiff<'a, T, D>{ /* private fields */ }Available on crate feature
blob only.Expand description
A helper that renders a Diff as unified diff output.
It can be used to create a textual diff in the format typically output by git
or gnu-diff if the -u option is used.
Implementations
Sourceimpl<'a, T, D> UnifiedDiff<'a, T, D>
impl<'a, T, D> UnifiedDiff<'a, T, D>
Sourcepub fn new(
diff: &'a Diff,
input: &'a InternedInput<T>,
consume_hunk: D,
context_size: ContextSize,
) -> Self
pub fn new( diff: &'a Diff, input: &'a InternedInput<T>, consume_hunk: D, context_size: ContextSize, ) -> Self
Create a new instance to create a unified diff from diff using the lines in input.
context_size is the amount of lines around each hunk which will be passed to consume_hunk.
consume_hunk is called for each hunk with all the information required to create a unified diff.