pub trait SliderHeuristic {
// Required method
fn best_slider_end(
&mut self,
tokens: &[Token],
hunk: Range<u32>,
earliest_end: u32,
) -> u32;
}Available on crate feature
blob only.Expand description
A trait for heuristics that determine the best position for ambiguous diff hunks.
During postprocessing, some hunks can be moved up or down without changing the minimal nature of the diff. This trait allows customizing the logic for choosing the optimal position for such hunks.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".