pub struct ConsumeBinaryHunk<'a, D> {
pub newline: &'a str,
pub delegate: D,
/* private fields */
}Available on crate feature
blob only.Expand description
An adapter with ConsumeHunk implementation to call a delegate which receives each stringified hunk.
Fields
newline: &'a strThe newline to use to separate lines if these don’t yet contain a newline. It should also be used to separate the stringified header from the hunk itself.
delegate: DThe delegate to receive stringified hunks.
Implementations
Sourceimpl<'a, D> ConsumeBinaryHunk<'a, D>where
D: ConsumeBinaryHunkDelegate,
impl<'a, D> ConsumeBinaryHunk<'a, D>where
D: ConsumeBinaryHunkDelegate,
Sourcepub fn new(delegate: D, newline: &'a str) -> ConsumeBinaryHunk<'a, D>
pub fn new(delegate: D, newline: &'a str) -> ConsumeBinaryHunk<'a, D>
Create a new instance that writes stringified hunks to delegate, which uses newline to separate header and hunk,
as well as hunk lines that don’t naturally end in a newline.