Module tracker

Module tracker 

Available on crate feature blob only.
Types related to the rename tracker for renames, rewrites and copies.

Deviation

Note that the algorithm implemented here is in many ways different from what git does.

  • it’s less sophisticated than git, but prefers a candidate whose file name matches the destination’s in identity matches, and uses that as a tie-breaker for similarity matches.
  • the set used for copy-detection is probably smaller by default.

Modules

emit
visit
A module with types used in the user-callback in Tracker::emit().

Enums

ChangeKind
The kind of a change.

Traits

Change
A trait providing all functionality to abstract over the concept of a change, as seen by the Tracker.